@@ -4,5 +4,5 @@ function(x,ci=.95) {
   s<-sd(x)
   n<-length(x)
   error<-qt(ci+(1-ci)/2,df=n-1)*s/sqrt(n)
-  return(c(a+error,a,a-error))
+  return(c(upper=a+error,mean=a,lower=a-error))
 }
