@@ -4,5 +4,5 @@ function(x) {
   s<-sd(x)
   n<-length(x)
   error<-(s/sqrt(n))
-  return(c(a+error,a,a-error))
+  return(c(upper=a+error,mean=a,lower=a-error))
 }
